netapp_ontap.models.ndmp_data API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ndmp_data`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NdmpDataSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NdmpData object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `bytes_processed: Size GET POST PATCH`

    Indicates the NDMP data bytes processed.

    Example: 5000

  `connection: NdmpConnect GET POST PATCH`

    Indicates the NDMP connection attributes.

  `operation: str GET POST PATCH`

    Indicates the NDMP data server operation.

    Valid choices:

    - backup
    - restore
    - none
  `reason: str GET POST PATCH`

    Indicates the reason for the NDMP data server halt.

  `state: str GET POST PATCH`

    Indicates the state of the NDMP data server.